Revision: 71846
          http://sourceforge.net/p/brlcad/code/71846
Author:   brlcad
Date:     2018-09-26 10:40:25 +0000 (Wed, 26 Sep 2018)
Log Message:
-----------
don't be so noisy about it as the messages are annoying, and bump the default 
to 1000x1000 (but not 1024x1024, that's too much)

Modified Paths:
--------------
    brlcad/trunk/src/libfb/if_ogl.c

Modified: brlcad/trunk/src/libfb/if_ogl.c
===================================================================
--- brlcad/trunk/src/libfb/if_ogl.c     2018-09-26 01:23:48 UTC (rev 71845)
+++ brlcad/trunk/src/libfb/if_ogl.c     2018-09-26 10:40:25 UTC (rev 71846)
@@ -480,12 +480,12 @@
     pixsize = ifp->if_height * ifp->if_width * sizeof(struct fb_pixel);
 
     /* shared memory behaves badly if we try to allocate too much, so
      * arbitrarily constrain it to our default 512x512 size & samller.
      */
-    if (pixsize > sizeof(struct fb_pixel)*512*512) {
+    if (pixsize > sizeof(struct fb_pixel)*1000*1000) {
        /* let the user know */
        ifp->if_mode |= MODE_1MALLOC;
-       fb_log("ogl_getmem: image too big for shared memory, using private\n");
+       /* fb_log("ogl_getmem: image too big for shared memory, using 
private\n"); */
     }
 
@@ -480,12 +480,12 @@
 
     /* shared memory behaves badly if we try to allocate too much, so
-     * arbitrarily constrain it to our default 512x512 size & samller.
+     * arbitrarily constrain it to our default 1000x1000 size & samller.
      */
     if ((ifp->if_mode & MODE_1MASK) == MODE_1MALLOC) {

This was sent by the SourceForge.net collaborative development platform, the 
world's largest Open Source development site.



_______________________________________________
BRL-CAD Source Commits mailing list
brlcad-commits@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/brlcad-commits

Reply via email to